.. Bowtie documentation master file, created by
   sphinx-quickstart on Fri Aug 19 23:07:25 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Comparison with Other Tools
===========================

Bowtie is designed to have a simple API to create dashboard applications quickly.
That being said let's compare this against similar Python libraries.

Pyxley
------

`Pyxley <http://pyxley.readthedocs.io/en/latest/index.html>`_

.. todo::
    compare to pyxley

Remi
----

`Remi <https://github.com/dddomodossola/remi>`_

.. todo::
    compare to remi

Dash
----

From Plotly is `Dash <https://github.com/plotly/dash>`_

.. todo::
    compare to dash

Shiny
-----

Not a Python library but is the gold standard in the R world.

.. todo::
    should try using shiny so I know what it's like
